/*
 * Kernel interface to machine-dependent clock driver.
 * Garrett Wollman, September 1994.
 * This file is in the public domain.
 *
 * $FreeBSD: src/sys/i386/include/clock.h,v 1.38.2.1 2002/11/02 04:41:50 iwasaki Exp $
 */


#ifndef _MACHINE_CLOCK_H_
#define	_MACHINE_CLOCK_H_

#include <sys/types.h>
#include <lib/lib.h>

#ifdef KERNEL

#define DELAY micro_timer

extern uint64 getCpuClock();
extern int	rtcin __P((int val));

#endif /* KERNEL */

#endif /* !_MACHINE_CLOCK_H_ */
